@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 1.06.
 package XML::Compile::Translate::Reader;
 use vars '$VERSION';
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 use base 'XML::Compile::Translate';
 
@@ -1015,7 +1015,7 @@ sub makeAnyElement
     my %no  = map { ($_ => 1) } @{$no  || []};
 
     # Takes all, before filtering
-    my $any = $max eq 'unbounded' || $max > 1
+    my $any = ($max eq 'unbounded' || $max > 1)
     ? sub
       {   my $tree  = shift or return ();
           my $count = 0;
@@ -1028,7 +1028,6 @@ sub makeAnyElement
 
               my $k = pack_type $ns, $child->localName;
               push @{$result{$k}}, $child;
-
               $count++;
               $tree->nextChild;
           }
